@@ -4,7 +4,7 @@ import shapely.geometry
 import geopandas as gpd
 from zipfile import ZipFile
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 
 REQUIRED_GTFS_FILES = [
@@ -91,6 +91,9 @@ def load_shapes(src):
         raise ValueError(
             f"Data type not supported: {type(src)}")
     
+    if 'shapes' not in df_dict:
+        raise Exception("shapes.txt not found in GTFS")
+
     items = []
     for shape_id, g in df_dict['shapes'].groupby('shape_id'):
         g = g.sort_values('shape_pt_sequence')
